#
# spec file for package singularity
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%define libsingularity libsingularity1

%define git_version 2.6.1

# slurm build broken
%define have_slurm 0

%define allow_suid 1

# for the perl git file parser to run, none of the 
# macros used in the variables must contain shell code.
%define github_ref %{?git_sha}%{!?git_sha:%git_version}

Name:           singularity
Version:        %git_version
Release:        lp151.2.3.1
Summary:        Application and environment virtualization
License:        BSD-3-Clause
Group:          Productivity/Clustering/Computing
Url:            http://singularity.lbl.gov/
#Source:		https://github.com/singularityware/%%{name}/tarball/%%{github_ref}#/%%{name}-%%{version}.tar.gz
Source:         https://github.com/singularityware/%{name}/archive/%{github_ref}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        README.SUSE
Source5:        singularity-rpmlintrc
Patch0:         CVE-2019-19724-2x.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
%if 0%{?have_slurm}
BuildRequires:  slurm-devel
%endif
BuildRequires:  fdupes
BuildRequires:  libarchive-devel
BuildRequires:  python
%{?allow_suid:Requires(pre):  shadow}
PreReq:         permissions >= 20170922
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Singularity provides functionality to build the smallest most minimal
possible containers, and running those containers as single application
environments.

%package devel
Summary:        Development package for Singularity
Group:          Development/Libraries/C and C++
Requires:       %{libsingularity} = %{version}
Requires:       %{name} = %{version}

%description devel
Development package for singularity. This package includes the header files
and libraries for the Singularity API.

%package -n %{libsingularity}
Summary:        Libraries for Singularity
Group:          System/Libraries

%description -n %{libsingularity}
This package contains the library needed to run programs dynamically linked
with Singularity.

%prep
%setup -q -n %{name}-%{github_ref}
cp %{S:1} .
%patch0 -p1

%build
./autogen.sh
%configure \
    %{!?allow_suid:--disable-suid} \
    --with-userns \
    --with-gnu-ld \
%if 0%{?have_slurm}
    --with-slurm
%endif

make %{?_smp_mflags} CFLAGS+=-fPIE LDFLAGS+=-pie

%install
%makeinstall
# remove static library stuff
rm -f %{buildroot}/%{_libdir}/%{name}/lib%{name}-*.a
rm -f %{buildroot}/%{_libdir}/%{name}/lib%{name}-*.la
# fix broken permissions
chmod a-x %{buildroot}/%{_libexecdir}/%{name}/python/docker/__init__.py
chmod a-x %{buildroot}/%{_libexecdir}/%{name}/python/__init__.py
mkdir -p %{buildroot}/%{_datadir}/bash-completion/completions/
mv %{buildroot}/%{_sysconfdir}/bash_completion.d/%{name} \
    %{buildroot}/%{_datadir}/bash-completion/completions/%{name}
%fdupes  %{buildroot}
for file in $(find %{buildroot}/%{_libexecdir} -name \*.py); do grep "/usr/bin/env" $file && sed -i 's@/usr/bin/env python@/usr/bin/python@' $file; done

%post -n %{libsingularity} -p /sbin/ldconfig

%postun -n %{libsingularity} -p /sbin/ldconfig

%if 0%{allow_suid:1}
%pre 
getent group %{name} >/dev/null || groupadd -r %{name}
exit 0

%post
%set_permissions %{_libexecdir}/%{name}/bin/expand-suid
%set_permissions %{_libexecdir}/%{name}/bin/mount-suid
%set_permissions %{_libexecdir}/%{name}/bin/create-suid
%set_permissions %{_libexecdir}/%{name}/bin/action-suid
%set_permissions %{_libexecdir}/%{name}/bin/export-suid
%set_permissions %{_libexecdir}/%{name}/bin/import-suid
%set_permissions %{_libexecdir}/%{name}/bin/start-suid

%verifyscript
%verify_permissions %{_libexecdir}/%{name}/bin/expand-suid
%verify_permissions %{_libexecdir}/%{name}/bin/mount-suid
%verify_permissions %{_libexecdir}/%{name}/bin/create-suid
%verify_permissions %{_libexecdir}/%{name}/bin/action-suid
%verify_permissions %{_libexecdir}/%{name}/bin/export-suid
%verify_permissions %{_libexecdir}/%{name}/bin/import-suid
%set_permissions %{_libexecdir}/%{name}/bin/start-suid
%endif

%if 0%{?sle_version} > 120200 || 0%{?suse_version} > 1320
%define files_license %license 
%else 
%define files_license %doc 
%endif

%files
%defattr(-,root,root)
%doc examples CONTRIBUTING.md README.md %{basename:%{S:1}}
%doc CONTRIBUTORS.md CHANGELOG.md LICENSE-LBNL.md
%files_license COPYRIGHT.md LICENSE.md
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/default-nsswitch.conf
%config(noreplace) %{_sysconfdir}/%{name}/init
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/nvliblist.conf
%{_datadir}/bash-completion/completions/%{name}
%{_bindir}/%{name}
%{_bindir}/run-%{name}
%{_libexecdir}/%{name}
%exclude %{_libdir}/%{name}/lib%{name}-*.so*
%{?allow_suid:%verify(not mode) %attr(4750,root,%{name}) %{_libexecdir}/%{name}/bin/*-suid}
%{_mandir}/man1/%{name}.1.gz
%{_var}/%{name}

%files -n %{libsingularity}
%defattr(-,root,root)
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib%{name}-*.so.*

%files devel
%defattr(-,root,root)
%dir /usr/include/%{name}
/usr/include/%{name}/*.h
%{_libdir}/%{name}/lib%{name}-*.so

%changelog
* Wed Jan  8 2020 Ana Guerrero Lopez <aguerrero@suse.com>
- Fix a security issue (CVE-2019-19724), incorrect file permissions
  on user configuration and cache directories. (boo#1159550)
  * Add patch CVE-2019-19724-2x.patch
* Mon Dec 17 2018 cgoll@suse.com
- Updated to 2.6.1 to fix CVE-2018-19295 (bsc#1111411).
  * mount points are not mounted with shared mount propagation by
    default anymore, as this may result in privilege escalation.
* Wed Oct 31 2018 matthias.gerstner@suse.com
- Also package the directory tree rooted at /var/singularity/.
  Otherwise running a container fails with:
  'Failed to resolve path to /var/singularity/mnt/container: No such file or directory'
* Sun Oct 14 2018 eich@suse.com
- Update to version 2.6.0
  * Allow admin to specify a non-standard location for mksquashfs binary at
    build time with '--with-mksquashfs' option #1662
  * '--nv' option will use
    [nvidia-container-cli](https://github.com/NVIDIA/libnvidia-container) if
    installed #1681
  * [nvliblist.conf]
    (https://github.com/singularityware/singularity/blob/master/etc/nvliblist.conf)
    now has a section for binaries #1681
  * '--nv' can be made default with all action commands in singularity.conf
    [#1681]
  * '--nv' can be controlled by env vars '$SINGULARITY_NV' and
    '$SINGULARITY_NV_OFF' #1681
  * Refactored travis build and packaging tests #1601
  * Added build and packaging tests for Debian 8/9 and openSUSE 42.3/15.0 #1713
  * Restore shim init process for proper signal handling and child reaping when
    container is initiated in its own PID namespace #1221
  * Add '-i' option to image.create to specify the inode ratio. #1759
  * Bind '/dev/nvidia*' into the container when the '--nv' flag is used in
    conjuction with the '--contain' flag #1358
  * Add '--no-home' option to not mount user $HOME if it is not the $CWD and
    'mount home = yes' is set. #1761
  * Added support for OAUTH2 Docker registries like Azure Container Registry
    [#1622]
  [#]## Bug fixes
  * Fix 404 when using Arch Linux bootstrap #1731
  * Fix environment variables clearing while starting instances #1766
* Mon Jul  9 2018 eich@suse.com
- Use %%license instead of %%doc for license files on newer products.
- Fix bash completion path.
* Fri Jul  6 2018 cgoll@suse.com
- Updated from 2.3.2 to 2.5.2
- Fix security issues for incorrect access control on systems
  supporting overlay file system descirbed in CVE-2018-12021 and
  bsc#1100333
  Highlights of 2.5.2
  * a new `build` command was added to replace `create` +
    `bootstrap`
  * default image format is squashfs, eliminating the need to
    specify a size
  * a `localimage` can be used as a build base, including ext3,
    sandbox, and other squashfs images
  * singularity hub can now be used as a base with the uri
  * Restore docker-extract aufs whiteout handling that implements
    correct extraction of docker container layers.
  * several bug fixes, see CHANGELOG.md for details
- Removed: singularity-2.3.2.tar.gz
- Added: singularity-2.5.2.tar.gz
- Removed 'notyet' if conditions in specfile to allow files
  introduced in v2.5.2
- Fixed access control on systems supporting overlay file system
  (CVE-2018-12021, boo#1100333).
* Mon Nov  6 2017 eich@suse.com
- Restrict permissions file version to a version which has
  the required singularity entries.
* Thu Nov  2 2017 eich@suse.com
- Update to 2.3.2:
  * Fix for a change that Docker implemented to their registry
    RESTful API which broke compatibility with Singularity.
  * Several other low minor fixes.
* Thu Oct  5 2017 eich@suse.com
- Removed:
  Do-chdir-before-duing-chroot.patch:
  After checking with the security team that there are no concerns
  about doing the chdir() after the chroot(), remove this patch and
  add a filter to keep rpmlint from complaining (bsc#1028304).
* Mon Oct  2 2017 eich@suse.com
- set permissions for SUID binaries to 4750.
- fix library packaging for i586.
- add a README.SUSE
- temporarily filter filter for non-standard-gid from rpmlint
  until group 'singularity' is available as known group.
* Thu Sep 14 2017 eich@suse.com
- Update to version 2.3.1:
  This release includes a fix for a High Severity security issue on older
  hosts, and other improvements and fixes to previous versions of Singularity.
  Version 2.3:
  There are a massive number of fixes, updates, optimizations and awesomeness
  contained within this release, but here is a brief overview of the major
  changes you can expect to find in this release:
    Lots of backend library changes to accommodate a more flexible API
    Restructured Python backend
    Updated bootstrap backend to make it much more reliable
    Direct support for the awesome, the fantastic, Singularity-Hub!
    Ability to run additional commands without root privileges (e.g. create,
    import, copy, export, etc..).
    Added ability to pull images from Singularity Hub and Docker
    Containers now have labels, and are inspect'able
- Do-chdir-before-duing-chroot.patch:
  Add a chdir() before chroot() just to keep rpmlint from complaining
  even more. There is a chdir("/") right after the chroot() call.
- Created group 'singularity' and make suid-root binaries only executable
  by this group.
* Sat Feb 18 2017 eich@suse.com
- Initial import of singuarity 2.2.1.
